# !/usr/bin/python

# Reference: https://github.com/iDuckDark/VisualSim


import os
import signal
from subprocess import Popen, PIPE


def kill_processes_bind_to_port(port):
    process = Popen(["lsof", "-i", ":{0}".format(port)], stdout=PIPE, stderr=PIPE)
    stdout, stderr = process.communicate()
    for process in str(stdout.decode("utf-8")).split("\n")[1:]:
        data = [x for x in process.split(" ") if x != '']
        if len(data) <= 1:
            continue
        os.kill(int(data[1]), signal.SIGKILL)


def visualsim():
    ports = [2222, 1900, 1099]
    [kill_processes_bind_to_port(_) for _ in ports]
    os.system("cd VS_LM && sh StartServer.sh & cd VS_AR && sh VisualSim.sh")



import click


@click.command()
@click.option('--verbose', is_flag=True, help="Will print verbose messages.")
@click.option('--name', default='', help='Who are you?')
def cli(verbose, name):
    if verbose:
        click.echo("We are in the verbose mode.")
    click.echo("Hello World. Welcome to PyNevin CLI")
    click.echo('Bye {0}'.format(name))



import pathlib
from setuptools import setup, find_packages
from pynevin.pypi import PyPi

HERE = pathlib.Path(__file__).parent

PACKAGE_NAME = 'pynevin'
VERSION = PyPi.get_latest_version(PACKAGE_NAME)
AUTHOR = 'Nevin WS Ganesan'
AUTHOR_EMAIL = 'PyNevin@idarkduck.com'
URL = 'https://github.com/iDuckDark/PyNevin'

LICENSE = 'Apache License 2.0'
DESCRIPTION = "Nevin's Python Packages: Algorithms, Utils, Leetcode & Helper functions"
LONG_DESCRIPTION = (HERE / "README.md").read_text()
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
    'click',
]

setup(name=PACKAGE_NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      long_description_content_type=LONG_DESC_TYPE,
      author=AUTHOR,
      license=LICENSE,
      author_email=AUTHOR_EMAIL,
      url=URL,
      install_requires=INSTALL_REQUIRES,
      packages=find_packages(),
      entry_points='''
            [console_scripts]
            pynevin=pynevin.cli:cli
        ''',
      )
